==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/el.php <==
<?php
return array(

	'item:object:file' => 'Αρχεία',
	'collection:object:file' => 'Files',
	'collection:object:file:all' => "All site files",
	'collection:object:file:owner' => "%s's files",
	'collection:object:file:friends' => "Friends' files",
	'collection:object:file:group' => "Group files",
	'add:object:file' => "Upload a file",
	'edit:object:file' => "Edit file",

	'file:more' => "Περισσότερα αρχεία",
	'file:list' => "Προβολή λίστας",

	'file:num_files' => "Αριθμός αρχείων για εμφάνιση",
	'file:replace' => 'Αντικατάσταση αρχείου (αφήστε το κενό για να μην αλλάξει το αρχείο)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Φίλων'",

	'file:file' => "Αρχείο",

	'file:list:list' => 'Εναλλαγή σε προβολή λίστας',
	'file:list:gallery' => 'Εναλλαγή σε προβολή εικονιδίων',

	'file:types' => "Μεταφορτωμένοι τύποι δεδομένων",

	'file:type:' => 'Αρχεία',
	'file:type:all' => "Όλα τα αρχεία",
	'file:type:video' => "Βίντεο",
	'file:type:document' => "Έγγραφα",
	'file:type:audio' => "Ήχος",
	'file:type:image' => "Εικόνες",
	'file:type:general' => "Γενικά",

	'file:user:type:video' => "%s βίντεο",
	'file:user:type:document' => "%s έγγραφα",
	'file:user:type:audio' => "%s ήχου",
	'file:user:type:image' => "%s εικόνες",
	'file:user:type:general' => "%s αρχεία γενικά",

	'file:friends:type:video' => "Τα βίντεο των φίλων σας",
	'file:friends:type:document' => "Τα έγγραφα των φίλων σας",
	'file:friends:type:audio' => "Τα αρχεία ήχου των φίλων σας",
	'file:friends:type:image' => "Οι εικόνες των φίλων σας",
	'file:friends:type:general' => "Τα αρχεία των φίλων σας",

	'widgets:filerepo:name' => "File widget",
	'widgets:filerepo:description' => "Showcase your latest files",

	'groups:tool:file' => 'Enable group files',

	'river:object:file:create' => '%s uploaded the file %s',
	'river:object:file:comment' => '%s commented on the file %s',

	'file:notify:summary' => 'Νέο αρχείο με όνομα %s',
	'file:notify:subject' => 'Νέο αρχείο: %s',
	'file:notify:body' => '%s uploaded a new file: %s

%s

View and comment on the file:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "The file was successfully saved.",
	'entity:delete:object:file:success' => "The file was successfully deleted.",

	/**
	 * Error messages
	 */

	'file:none' => "Δεν υπάρχουν αρχεία.",
	'file:uploadfailed' => "Αδύνατη η αποθήκευση του αρχείου.",
	'file:noaccess' => "Δεν έχετε δικαιώματα αλλαγής του αρχείου",
	'file:cannotload' => "Σφάλμα κατά τη μεταφόρτωση του αρχείου",
);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/file/languages/el.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(

	'item:object:file' => 'Αρχεία',
	'collection:object:file' => 'Αρχεία',
	'collection:object:file:all' => "All site files",
	'collection:object:file:owner' => "%s's files",
	'collection:object:file:friends' => "Friends' files",
	'collection:object:file:group' => "Group files",
	'add:object:file' => "Upload a file",
	'edit:object:file' => "Edit file",

	'file:more' => "Περισσότερα αρχεία",
	'file:list' => "Προβολή λίστας",

	'file:num_files' => "Αριθμός αρχείων για εμφάνιση",
	'file:replace' => 'Αντικατάσταση αρχείου (αφήστε το κενό για να μην αλλάξει το αρχείο)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Φίλων'",

	'file:file' => "Αρχείο",

	'file:list:list' => 'Εναλλαγή σε προβολή λίστας',
	'file:list:gallery' => 'Εναλλαγή σε προβολή εικονιδίων',

	'file:types' => "Μεταφορτωμένοι τύποι δεδομένων",

	'file:type:' => 'Αρχεία',
	'file:type:all' => "Όλα τα αρχεία",
	'file:type:video' => "Βίντεο",
	'file:type:document' => "Έγγραφα",
	'file:type:audio' => "Ήχος",
	'file:type:image' => "Εικόνες",
	'file:type:general' => "Γενικά",

	'file:user:type:video' => "%s βίντεο",
	'file:user:type:document' => "%s έγγραφα",
	'file:user:type:audio' => "%s ήχου",
	'file:user:type:image' => "%s εικόνες",
	'file:user:type:general' => "%s αρχεία γενικά",

	'file:friends:type:video' => "Τα βίντεο των φίλων σας",
	'file:friends:type:document' => "Τα έγγραφα των φίλων σας",
	'file:friends:type:audio' => "Τα αρχεία ήχου των φίλων σας",
	'file:friends:type:image' => "Οι εικόνες των φίλων σας",
	'file:friends:type:general' => "Τα αρχεία των φίλων σας",

	'widgets:filerepo:name' => "Εφαρμογή αρχείου",
	'widgets:filerepo:description' => "Εμφάνιση των πιο πρόσφατων αρχείων σας",

	'groups:tool:file' => 'Enable group files',

	'river:object:file:create' => '%s uploaded the file %s',
	'river:object:file:comment' => '%s commented on the file %s',

	'file:notify:summary' => 'Νέο αρχείο με όνομα %s',
	'file:notify:subject' => 'Νέο αρχείο: %s',
	'file:notify:body' => '%s uploaded a new file: %s

%s

View and comment on the file:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "The file was successfully saved.",
	'entity:delete:object:file:success' => "The file was successfully deleted.",

	/**
	 * Error messages
	 */

	'file:none' => "Δεν υπάρχουν αρχεία.",
	'file:uploadfailed' => "Αδύνατη η αποθήκευση του αρχείου.",
	'file:noaccess' => "Δεν έχετε δικαιώματα αλλαγής του αρχείου",
	'file:cannotload' => "Σφάλμα κατά τη μεταφόρτωση του αρχείου",
);
